.. _glossary:

Glossary
========

.. glossary::
   
    PN
        Package name in Gentoo syntax. Example: jinja2

    MY_PN
        Package name used in ebuilds converted from :term:`PN` to match upstream package name.

    PV
        Package version in Gentoo syntax. Example: 0.1_beta3

    MY_PV
        Package version used in ebuilds converted from :term:`PV` to match upstream package version.

    MY_P
        Package name and version in Gentoo syntax. Example: jinja2-0.1_beta3

    SRC_URI
        URI string from where source code is downloaded.

    HOMEPAGE
        Homepage address of a package.

    LICENSE
        License which software is copyrighted under

    DEPEND
        List of dependencies needed for compiling/setup

    RDEPEND
        List of runtime dependencies

    S
        Working directory while portage is emerging an ebuild

    PYTHON_MODNAME
        List of python module names in this ebuild

    PyPi
        Python Package Index (CPAN alike repository for packages) — http://pypi.python.org/pypi

    DESCRIPTION
        Portage variable, short description of an ebuild program

    AUTHOR
        Person who initially wrote the program

    eclass
        Bash script provided by portage for handling ebuilds
        
